# Generated by Django 4.2.10 on 2024-02-22 03:52

import _socket
from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_crf.model_mixins.crf_status_model_mixin
import edc_model.validators.date
import edc_model_fields.fields.custom_django_fields
import edc_model_fields.fields.other_charfield
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("intecomm_subject", "0142_alter_historicalhtninitialreview_managed_by_old_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="HistoricalCareseekingB",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                        verbose_name="Hostname created",
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                        verbose_name="Hostname modified",
                    ),
                ),
                (
                    "device_created",
                    models.CharField(blank=True, max_length=10, verbose_name="Device created"),
                ),
                (
                    "device_modified",
                    models.CharField(
                        blank=True, max_length=10, verbose_name="Device modified"
                    ),
                ),
                (
                    "locale_created",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale created",
                    ),
                ),
                (
                    "locale_modified",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale modified",
                    ),
                ),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("consent_model", models.CharField(editable=False, max_length=50, null=True)),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "ill_month",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        metadata="FILLMONTH1",
                        verbose_name="Other than today’s visit, and thinking about the past 3 months, were you ill or in need of healthcare at any point for HIV, Hypertension, Diabetes or anything related to you having these conditions?",
                    ),
                ),
                (
                    "seek_advice",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="from a public facility, local pharmacy, traditional doctor, etc",
                        max_length=15,
                        metadata="FSEEK1",
                        verbose_name="Did you seek advice or treatment?",
                    ),
                ),
                (
                    "no_seek_advice",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("not_necessary", "Did not think it was necessary "),
                            ("recovered", "Recovered before I could go "),
                            (
                                "home_remedy",
                                "Home remedy given by family member, relatives, neighbours ",
                            ),
                            ("too_expensive", "Too expensive "),
                            ("no_time", "Wanted to but could not find time"),
                            ("no_transport", "There was no one to take me"),
                            (
                                "facility_too_far",
                                "The health facility is too far/ not easy to reach ",
                            ),
                            (
                                "hcw_unavailable",
                                "Health care practitioner mostly unavailable ",
                            ),
                            ("med_problems", "Taking medicines caused problems"),
                            (
                                "hcw_confusing",
                                "Do not understand what the healthcare practitioner says ",
                            ),
                            (
                                "hcw_incompetent",
                                "Practitioner is not competent in their work ",
                            ),
                            ("OTHER", "Other (specify)"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        metadata="FNOSEEK1",
                        verbose_name="If no, why did you not seek advice or treatment?",
                    ),
                ),
                (
                    "no_seek_advice_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If OTHER reason, please explain ...",
                    ),
                ),
                (
                    "seek_facility",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("comm_health_centre", "Community health centre/health post"),
                            ("gov_dispensary", "Government dispensary"),
                            ("phc", "Primary health care center (PHC)"),
                            ("private_clinic", "Private clinic"),
                            ("ngo", "NGO clinic"),
                            ("public_hospital", "Public Hospital"),
                            ("private_hospital", "Private hospital"),
                            ("pharmacy", "Pharmacy"),
                            ("hcw_home", "Any healthcare practitioner’s home"),
                            ("OTHER", "Other (specify)"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        metadata="FSEEKFAC1",
                        verbose_name="If yes, where did you seek advice or treatment?",
                    ),
                ),
                (
                    "seek_facility_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If OTHER place, please explain ...",
                    ),
                ),
                (
                    "seek_care_type",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("outpatient", "Outpatient (includes laboratory testing)"),
                            ("inpatient", "Inpatient"),
                            ("both", "Both"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        metadata="FSEEKTYPE1",
                        verbose_name="If yes, what type of care was this?",
                    ),
                ),
                (
                    "seek_outpatient_visits",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        metadata="FOUT1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(1),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="If yes and OUTPATIENT, how many visits in total?",
                    ),
                ),
                (
                    "travel_duration",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        metadata="FOUTTRATIME1",
                        validators=[
                            django.core.validators.RegexValidator(
                                "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                                message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                            )
                        ],
                        verbose_name="How long did it take you to get there?",
                    ),
                ),
                (
                    "travel_costs",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency",
                        metadata="FOUTTRACOST1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="Thinking about yourself and anyone that accompanied you, how much was spent on travel from your home to your last/most recent visit?",
                    ),
                ),
                (
                    "food_costs",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency",
                        metadata="FOUTFOODCOST1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="Thinking about yourself and anyone that accompanied you, did you have to pay for food, drink or other refreshments during your travel or during your last/most recent visit? (e.g. food, drink, etc.)",
                    ),
                ),
                (
                    "care_costs",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency",
                        metadata="FOUTFEECOST1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="How much money did you spend on healthworker and consultation fees during your last/most recent visit?",
                    ),
                ),
                (
                    "meds_prescribed",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        metadata="FOUTMED1",
                        verbose_name="Were you prescribed any medicines during your last/most recent visit?",
                    ),
                ),
                (
                    "med_conditions_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FOUTMEDCONDOTHER1",
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "med_collected",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        metadata="FOUTMEDCOLL1",
                        verbose_name="Did you receive/collect these medicines (whether paid or received for free)?",
                    ),
                ),
                (
                    "med_not_collected_reason",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("meds_at_home", "Already had the medicines at home"),
                            ("unavailable", "Medicines were not available"),
                            ("expensive", "Medicines were too expensive"),
                            ("home_remedies", "Home remedies are better"),
                            (
                                "unimportant",
                                "Did not think it was important to get these medicines",
                            ),
                            ("too_busy", "Did not have the time to collect or buy medicines"),
                            ("problematic", "Taking medicines caused problems"),
                            ("OTHER", "Other, please specify ..."),
                        ],
                        max_length=25,
                        metadata="FOUTMEDNO1",
                        verbose_name="Why were these medicines not received/collected?",
                    ),
                ),
                (
                    "med_not_collected_reason_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FOUTMEDNOOTHER1",
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "med_cost_tot",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FOUTMEDCOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on these medicines? ",
                    ),
                ),
                (
                    "tests_requested",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="for example, blood pressure, viral load, glucose etc.",
                        max_length=25,
                        metadata="FOUTTEST1",
                        verbose_name="Did the healthcare worker request for any tests to be done during your last/most recent visit?",
                    ),
                ),
                (
                    "tests_done",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=25,
                        metadata="FOUTTESTDONE1",
                        verbose_name="Were the tests performed?",
                    ),
                ),
                (
                    "tests_not_done_reason",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("unavailable", "Tests were not available"),
                            ("expensive", "Tests were too expensive"),
                            (
                                "unimportant",
                                "Did not think it was important to do these tests ",
                            ),
                            ("too_busy", "Did not have the time to do these tests"),
                            ("OTHER", "Other, please specify ..."),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        metadata="FOUTTESTNO1",
                        verbose_name="Why were the tests not performed?",
                    ),
                ),
                (
                    "tests_not_done_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FOUTTESTNOOTHER1",
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "tests_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FOUTTESTCOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much did you spend on these tests?",
                    ),
                ),
                (
                    "facility_duration",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        metadata="FOUTTIME1",
                        validators=[
                            django.core.validators.RegexValidator(
                                "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                                message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                            )
                        ],
                        verbose_name="Roughly how much time did you spend during your last/most recent visit?",
                    ),
                ),
                (
                    "facility_visit_alt",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            (
                                "paid_work",
                                "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                            ),
                            (
                                "unpaid_work",
                                "Unpaid work (e.g. subsistence farming, housework etc.)",
                            ),
                            ("OTHER", "Other (specify)"),
                        ],
                        max_length=25,
                        metadata="FOUTACTIVITY1",
                        verbose_name="If you were not attending the visit, what would you have been doing?",
                    ),
                ),
                (
                    "alt_lost_income",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency. Ask for cash value or equivalent cash value for in-kind",
                        metadata="FOUTPAID1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="How much would you have made in cash or in-kind for a day’s work?",
                    ),
                ),
                (
                    "accompany_num",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        metadata="FOUTACMPNUM1"
                    ),
                ),
                (
                    "accompany_wait",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        metadata="FOUTACMPWAIT1",
                        verbose_name="Did the people accompanying you wait for you during your last/most recent visit?",
                    ),
                ),
                (
                    "accompany_alt",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        blank=True,
                        choices=[
                            (
                                "paid_work",
                                "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                            ),
                            (
                                "unpaid_work",
                                "Unpaid work (e.g. subsistence farming, housework etc.)",
                            ),
                            ("OTHER", "Other (specify)"),
                        ],
                        max_length=25,
                        metadata="FOUTACMPACT1",
                        null=True,
                        verbose_name="If those accompanying you were not attending your last/most recent visit with you, what would they have been doing?",
                    ),
                ),
                (
                    "accompany_lost_income",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency. Ask for cash value or equivalent cash value for in-kind",
                        metadata="FOUTACMPPAID1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="How much would they have made in cash or in-kind for a day’s work?",
                    ),
                ),
                (
                    "money_sources_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FOUTSOURCEOTHER",
                        null=True,
                        verbose_name="If other 'source of payment', please specify ...",
                    ),
                ),
                (
                    "money_source_main",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                            (
                                "family_gift",
                                "Loan from family members that does not need to be repaid",
                            ),
                            ("family_loan", "Loan from family member that needs to be repaid"),
                            (
                                "gift_relative",
                                "Loan from relative/neighbour that does not need to be repaid",
                            ),
                            (
                                "loan_relative",
                                "Loan from relative/neighbour that needs to be repaid",
                            ),
                            ("loan_money_lender", "Loan from money lender"),
                            ("loan_bank", "Loan from another source eg bank"),
                            ("community", "Self-help community group"),
                            ("national_insurance", "National health insurance"),
                            ("private_insurance", "Private health insurance"),
                            ("community_insurance", "Community health insurance"),
                            ("waiver", "Government waiver"),
                            (
                                "asset_sale",
                                "Sale of assets (property, livestock, jewellery, household goods, etc)",
                            ),
                            ("OTHER", "Other (specify)"),
                        ],
                        max_length=25,
                        metadata="FOUTSOURCEMAIN1",
                        verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
                    ),
                ),
                (
                    "seek_inpatient_visits",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        metadata="FINDAYS1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(1),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="How many days in total were you admitted as an INPATIENT?",
                    ),
                ),
                (
                    "inpatient_reasons_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FINDAYSCOND1",
                        null=True,
                        verbose_name="If other 'INPATIENT care' reason, please specify ...",
                    ),
                ),
                (
                    "inpatient_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FINCOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent in total on your hospital stay?",
                    ),
                ),
                (
                    "inpatient_accompany",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        help_text="for example: guesthouse, hotel, friend or relative’s house",
                        max_length=15,
                        metadata="FINACMP1",
                        verbose_name="Did anyone stay with you at the facility or somewhere else at night?",
                    ),
                ),
                (
                    "inpatient_food",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("dont_know", "Don't know"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        metadata="FINFOOD1",
                        verbose_name="When you were first admitted to the facility, was any food and drink bought for people who accompanied you?",
                    ),
                ),
                (
                    "inpatient_food_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FINFOODCOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on this food and drink?",
                    ),
                ),
                (
                    "inpatient_nowork_days",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        metadata="FINWRKMISS1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(90),
                        ],
                        verbose_name="When you were ill, how many days were you not able to go to work?",
                    ),
                ),
                (
                    "inpatient_accompany_nowork",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        metadata="FINOWRKMISS1",
                        verbose_name="Apart from the person that accompanied you, was there anyone else in your household who could not go to work because of your illness?",
                    ),
                ),
                (
                    "inpatient_accompany_nowork_days",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        metadata="FINODAYSMISS1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(90),
                        ],
                        verbose_name="How many days did they not go to work?",
                    ),
                ),
                (
                    "inpatient_money_sources_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FINSOURCEOTHER",
                        null=True,
                        verbose_name="If other 'source of payment', please specify ...",
                    ),
                ),
                (
                    "inpatient_money_sources_main_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FINSOURCEMAIN1OTHER",
                        null=True,
                        verbose_name="If other main 'source of payment', please specify ...",
                    ),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4, editable=False, primary_key=True, serialize=False
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="intecomm_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Cost of Careseeking: Part B",
                "verbose_name_plural": "historical Cost of Careseeking: Part B",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="HistoricalCareseekingA",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                        verbose_name="Hostname created",
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                        verbose_name="Hostname modified",
                    ),
                ),
                (
                    "device_created",
                    models.CharField(blank=True, max_length=10, verbose_name="Device created"),
                ),
                (
                    "device_modified",
                    models.CharField(
                        blank=True, max_length=10, verbose_name="Device modified"
                    ),
                ),
                (
                    "locale_created",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale created",
                    ),
                ),
                (
                    "locale_modified",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale modified",
                    ),
                ),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("consent_model", models.CharField(editable=False, max_length=50, null=True)),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "travel_time",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        metadata="FTRATIME1",
                        validators=[
                            django.core.validators.RegexValidator(
                                "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                                message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                            )
                        ],
                        verbose_name="How long did it take you to reach here?",
                    ),
                ),
                (
                    "travel_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="in local currency",
                        metadata="FTRAVCOST1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(1),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="Thinking about yourself and anyone that accompanied you, how much was spent on travel from your home to reach here?",
                    ),
                ),
                (
                    "food_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="in local currency",
                        metadata="FFOODCOST1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="Thinking about yourself and anyone that accompanied you, how much did you have to pay for food, drink or other refreshments during your travel or during your visit? (e.g. food, drink, etc.)",
                    ),
                ),
                (
                    "visit_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FFEECOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much money did you spend on healthworker and consultation fees during this visit?",
                    ),
                ),
                (
                    "med_prescribed",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        metadata="FMED1",
                        verbose_name="Were you prescribed any medicines during this visit?",
                    ),
                ),
                (
                    "med_conditions_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FMEDCONDOTHER1",
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "med_collected",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        metadata="FMEDCOLL1",
                        verbose_name="Did you receive/collect these medicines (whether paid or received for free)?",
                    ),
                ),
                (
                    "med_not_collected_reason",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("meds_at_home", "Already had the medicines at home"),
                            ("unavailable", "Medicines were not available"),
                            ("expensive", "Medicines were too expensive"),
                            ("home_remedies", "Home remedies are better"),
                            (
                                "unimportant",
                                "Did not think it was important to get these medicines",
                            ),
                            ("too_busy", "Did not have the time to collect or buy medicines"),
                            ("problematic", "Taking medicines caused problems"),
                            ("OTHER", "Other, please specify ..."),
                        ],
                        max_length=25,
                        metadata="FMED1",
                        verbose_name="Why were these medicines not received/collected?",
                    ),
                ),
                (
                    "med_not_collected_reason_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FMEDOTHER1",
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "med_cost_tot",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FMEDCOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on these medicines? ",
                    ),
                ),
                (
                    "med_cost_hiv",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="Leave blank if not applicable. In local currency",
                        metadata="FMEDCOSTHIV1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on HIV medicines? ",
                    ),
                ),
                (
                    "med_cost_htn",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="Leave blank if not applicable. In local currency",
                        metadata="FMEDCOSTHTN1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on Hypertension medicines? ",
                    ),
                ),
                (
                    "med_cost_dm",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="Leave blank if not applicable. In local currency",
                        metadata="FMEDCOSTDM1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on Diabetes medicines? ",
                    ),
                ),
                (
                    "med_cost_other",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="Leave blank if not applicable. In local currency",
                        metadata="FMEDCOSTOTHER1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on OTHER medicines? ",
                    ),
                ),
                (
                    "tests_requested",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        metadata="FTEST1",
                        verbose_name="Did the healthcare worker request for any tests to be done during this visit?",
                    ),
                ),
                (
                    "tests_done",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=25,
                        metadata="FTESTDONE1",
                        verbose_name="Were the tests performed?",
                    ),
                ),
                (
                    "tests_not_done_reason",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("unavailable", "Tests were not available"),
                            ("expensive", "Tests were too expensive"),
                            (
                                "unimportant",
                                "Did not think it was important to do these tests ",
                            ),
                            ("too_busy", "Did not have the time to do these tests"),
                            ("OTHER", "Other, please specify ..."),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        metadata="FTESTNO1",
                        verbose_name="Why were the tests not performed?",
                    ),
                ),
                (
                    "tests_not_done_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FTESTNOOTHER1",
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "tests_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FTESTCOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much did you spend on these tests?",
                    ),
                ),
                (
                    "facility_duration",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        metadata="FFACTIME1",
                        validators=[
                            django.core.validators.RegexValidator(
                                "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                                message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                            )
                        ],
                        verbose_name="How much time did you spend during your visit today -- from arrival to this place until the end of your visit?",
                    ),
                ),
                (
                    "wait_duration",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        metadata="FWAITIME1",
                        validators=[
                            django.core.validators.RegexValidator(
                                "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                                message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                            )
                        ],
                        verbose_name="How much time did you spend waiting?",
                    ),
                ),
                (
                    "hworker_duration",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        metadata="FWORKTIME1",
                        validators=[
                            django.core.validators.RegexValidator(
                                "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                                message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                            )
                        ],
                        verbose_name="How much time did you spend with the healthcare worker?",
                    ),
                ),
                (
                    "facility_visit_alt",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            (
                                "paid_work",
                                "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                            ),
                            (
                                "unpaid_work",
                                "Unpaid work (e.g. subsistence farming, housework etc.)",
                            ),
                            ("OTHER", "Other (specify)"),
                        ],
                        max_length=25,
                        metadata="FACTIVITY1",
                        verbose_name="If you were not attending the visit today, what would you have been doing?",
                    ),
                ),
                (
                    "alt_lost_income",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency. Ask for cash value or equivalent cash value for in-kind",
                        metadata="FPAID1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="How much would you have made in cash or in-kind for a day’s work?",
                    ),
                ),
                (
                    "referral",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        metadata="FREFER1",
                        verbose_name="As a result of your visit today, have you been referred for further care?",
                    ),
                ),
                (
                    "referral_type",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("inpatient", "Inpatient"),
                            ("outpatient", "Outpatient (includes laboratory testing)"),
                        ],
                        max_length=25,
                        metadata="FREFTYPE1",
                        verbose_name="Is this for inpatient or outpatient care?",
                    ),
                ),
                (
                    "referral_facility",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("public_clinic", "Public facility below tertiary level"),
                            ("private_clinic", "Private clinic"),
                            ("private_dx_facility", "Private diagnostic facility"),
                            ("ngo_clinic", "NGO clinic"),
                            ("public_hospital", "Public Hospital/tertiary facility"),
                            ("private_hospital", "Private hospital"),
                            ("pharmacy", "Pharmacy"),
                        ],
                        max_length=25,
                        metadata="FREFAC1",
                        verbose_name="What type of facility have you been referred to?",
                    ),
                ),
                (
                    "accompany_num",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        metadata="FACMP1"
                    ),
                ),
                (
                    "accompany_wait",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        metadata="FACMPWAIT1",
                        verbose_name="Did the people accompanying you wait for you during the visit?",
                    ),
                ),
                (
                    "accompany_alt",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        blank=True,
                        choices=[
                            (
                                "paid_work",
                                "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                            ),
                            (
                                "unpaid_work",
                                "Unpaid work (e.g. subsistence farming, housework etc.)",
                            ),
                            ("OTHER", "Other (specify)"),
                        ],
                        max_length=25,
                        metadata="FACMPACT1",
                        null=True,
                        verbose_name="If those accompanying you were not attending the visit with you today, what would they have been doing?",
                    ),
                ),
                (
                    "accompany_lost_income",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency. Ask for cash value or equivalent cash value for in-kind",
                        metadata="FACMP1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="How much would they have made in cash or in-kind for a day’s work?",
                    ),
                ),
                (
                    "money_sources_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FTODSOURCEOTHER",
                        null=True,
                        verbose_name="If other 'source of payment', please specify ...",
                    ),
                ),
                (
                    "money_source_main",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                            (
                                "family_gift",
                                "Loan from family members that does not need to be repaid",
                            ),
                            ("family_loan", "Loan from family member that needs to be repaid"),
                            (
                                "gift_relative",
                                "Loan from relative/neighbour that does not need to be repaid",
                            ),
                            (
                                "loan_relative",
                                "Loan from relative/neighbour that needs to be repaid",
                            ),
                            ("loan_money_lender", "Loan from money lender"),
                            ("loan_bank", "Loan from another source eg bank"),
                            ("community", "Self-help community group"),
                            ("national_insurance", "National health insurance"),
                            ("private_insurance", "Private health insurance"),
                            ("community_insurance", "Community health insurance"),
                            ("waiver", "Government waiver"),
                            (
                                "asset_sale",
                                "Sale of assets (property, livestock, jewellery, household goods, etc)",
                            ),
                            ("OTHER", "Other (specify)"),
                        ],
                        max_length=25,
                        metadata="FTODSOURCEMAIN1",
                        verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
                    ),
                ),
                (
                    "money_source_main_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other main 'source of payment', please specify ...",
                    ),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4, editable=False, primary_key=True, serialize=False
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="intecomm_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Cost of Careseeking: Part A",
                "verbose_name_plural": "historical Cost of Careseeking: Part A",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="CareseekingB",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                        verbose_name="Hostname created",
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                        verbose_name="Hostname modified",
                    ),
                ),
                (
                    "device_created",
                    models.CharField(blank=True, max_length=10, verbose_name="Device created"),
                ),
                (
                    "device_modified",
                    models.CharField(
                        blank=True, max_length=10, verbose_name="Device modified"
                    ),
                ),
                (
                    "locale_created",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale created",
                    ),
                ),
                (
                    "locale_modified",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale modified",
                    ),
                ),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("consent_model", models.CharField(editable=False, max_length=50, null=True)),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "ill_month",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        metadata="FILLMONTH1",
                        verbose_name="Other than today’s visit, and thinking about the past 3 months, were you ill or in need of healthcare at any point for HIV, Hypertension, Diabetes or anything related to you having these conditions?",
                    ),
                ),
                (
                    "seek_advice",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="from a public facility, local pharmacy, traditional doctor, etc",
                        max_length=15,
                        metadata="FSEEK1",
                        verbose_name="Did you seek advice or treatment?",
                    ),
                ),
                (
                    "no_seek_advice",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("not_necessary", "Did not think it was necessary "),
                            ("recovered", "Recovered before I could go "),
                            (
                                "home_remedy",
                                "Home remedy given by family member, relatives, neighbours ",
                            ),
                            ("too_expensive", "Too expensive "),
                            ("no_time", "Wanted to but could not find time"),
                            ("no_transport", "There was no one to take me"),
                            (
                                "facility_too_far",
                                "The health facility is too far/ not easy to reach ",
                            ),
                            (
                                "hcw_unavailable",
                                "Health care practitioner mostly unavailable ",
                            ),
                            ("med_problems", "Taking medicines caused problems"),
                            (
                                "hcw_confusing",
                                "Do not understand what the healthcare practitioner says ",
                            ),
                            (
                                "hcw_incompetent",
                                "Practitioner is not competent in their work ",
                            ),
                            ("OTHER", "Other (specify)"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        metadata="FNOSEEK1",
                        verbose_name="If no, why did you not seek advice or treatment?",
                    ),
                ),
                (
                    "no_seek_advice_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If OTHER reason, please explain ...",
                    ),
                ),
                (
                    "seek_facility",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("comm_health_centre", "Community health centre/health post"),
                            ("gov_dispensary", "Government dispensary"),
                            ("phc", "Primary health care center (PHC)"),
                            ("private_clinic", "Private clinic"),
                            ("ngo", "NGO clinic"),
                            ("public_hospital", "Public Hospital"),
                            ("private_hospital", "Private hospital"),
                            ("pharmacy", "Pharmacy"),
                            ("hcw_home", "Any healthcare practitioner’s home"),
                            ("OTHER", "Other (specify)"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        metadata="FSEEKFAC1",
                        verbose_name="If yes, where did you seek advice or treatment?",
                    ),
                ),
                (
                    "seek_facility_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If OTHER place, please explain ...",
                    ),
                ),
                (
                    "seek_care_type",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("outpatient", "Outpatient (includes laboratory testing)"),
                            ("inpatient", "Inpatient"),
                            ("both", "Both"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        metadata="FSEEKTYPE1",
                        verbose_name="If yes, what type of care was this?",
                    ),
                ),
                (
                    "seek_outpatient_visits",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        metadata="FOUT1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(1),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="If yes and OUTPATIENT, how many visits in total?",
                    ),
                ),
                (
                    "travel_duration",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        metadata="FOUTTRATIME1",
                        validators=[
                            django.core.validators.RegexValidator(
                                "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                                message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                            )
                        ],
                        verbose_name="How long did it take you to get there?",
                    ),
                ),
                (
                    "travel_costs",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency",
                        metadata="FOUTTRACOST1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="Thinking about yourself and anyone that accompanied you, how much was spent on travel from your home to your last/most recent visit?",
                    ),
                ),
                (
                    "food_costs",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency",
                        metadata="FOUTFOODCOST1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="Thinking about yourself and anyone that accompanied you, did you have to pay for food, drink or other refreshments during your travel or during your last/most recent visit? (e.g. food, drink, etc.)",
                    ),
                ),
                (
                    "care_costs",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency",
                        metadata="FOUTFEECOST1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="How much money did you spend on healthworker and consultation fees during your last/most recent visit?",
                    ),
                ),
                (
                    "meds_prescribed",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        metadata="FOUTMED1",
                        verbose_name="Were you prescribed any medicines during your last/most recent visit?",
                    ),
                ),
                (
                    "med_conditions_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FOUTMEDCONDOTHER1",
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "med_collected",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        metadata="FOUTMEDCOLL1",
                        verbose_name="Did you receive/collect these medicines (whether paid or received for free)?",
                    ),
                ),
                (
                    "med_not_collected_reason",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("meds_at_home", "Already had the medicines at home"),
                            ("unavailable", "Medicines were not available"),
                            ("expensive", "Medicines were too expensive"),
                            ("home_remedies", "Home remedies are better"),
                            (
                                "unimportant",
                                "Did not think it was important to get these medicines",
                            ),
                            ("too_busy", "Did not have the time to collect or buy medicines"),
                            ("problematic", "Taking medicines caused problems"),
                            ("OTHER", "Other, please specify ..."),
                        ],
                        max_length=25,
                        metadata="FOUTMEDNO1",
                        verbose_name="Why were these medicines not received/collected?",
                    ),
                ),
                (
                    "med_not_collected_reason_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FOUTMEDNOOTHER1",
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "med_cost_tot",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FOUTMEDCOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on these medicines? ",
                    ),
                ),
                (
                    "tests_requested",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="for example, blood pressure, viral load, glucose etc.",
                        max_length=25,
                        metadata="FOUTTEST1",
                        verbose_name="Did the healthcare worker request for any tests to be done during your last/most recent visit?",
                    ),
                ),
                (
                    "tests_done",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=25,
                        metadata="FOUTTESTDONE1",
                        verbose_name="Were the tests performed?",
                    ),
                ),
                (
                    "tests_not_done_reason",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("unavailable", "Tests were not available"),
                            ("expensive", "Tests were too expensive"),
                            (
                                "unimportant",
                                "Did not think it was important to do these tests ",
                            ),
                            ("too_busy", "Did not have the time to do these tests"),
                            ("OTHER", "Other, please specify ..."),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        metadata="FOUTTESTNO1",
                        verbose_name="Why were the tests not performed?",
                    ),
                ),
                (
                    "tests_not_done_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FOUTTESTNOOTHER1",
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "tests_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FOUTTESTCOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much did you spend on these tests?",
                    ),
                ),
                (
                    "facility_duration",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        metadata="FOUTTIME1",
                        validators=[
                            django.core.validators.RegexValidator(
                                "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                                message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                            )
                        ],
                        verbose_name="Roughly how much time did you spend during your last/most recent visit?",
                    ),
                ),
                (
                    "facility_visit_alt",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            (
                                "paid_work",
                                "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                            ),
                            (
                                "unpaid_work",
                                "Unpaid work (e.g. subsistence farming, housework etc.)",
                            ),
                            ("OTHER", "Other (specify)"),
                        ],
                        max_length=25,
                        metadata="FOUTACTIVITY1",
                        verbose_name="If you were not attending the visit, what would you have been doing?",
                    ),
                ),
                (
                    "alt_lost_income",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency. Ask for cash value or equivalent cash value for in-kind",
                        metadata="FOUTPAID1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="How much would you have made in cash or in-kind for a day’s work?",
                    ),
                ),
                (
                    "accompany_num",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        metadata="FOUTACMPNUM1"
                    ),
                ),
                (
                    "accompany_wait",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        metadata="FOUTACMPWAIT1",
                        verbose_name="Did the people accompanying you wait for you during your last/most recent visit?",
                    ),
                ),
                (
                    "accompany_alt",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        blank=True,
                        choices=[
                            (
                                "paid_work",
                                "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                            ),
                            (
                                "unpaid_work",
                                "Unpaid work (e.g. subsistence farming, housework etc.)",
                            ),
                            ("OTHER", "Other (specify)"),
                        ],
                        max_length=25,
                        metadata="FOUTACMPACT1",
                        null=True,
                        verbose_name="If those accompanying you were not attending your last/most recent visit with you, what would they have been doing?",
                    ),
                ),
                (
                    "accompany_lost_income",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency. Ask for cash value or equivalent cash value for in-kind",
                        metadata="FOUTACMPPAID1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="How much would they have made in cash or in-kind for a day’s work?",
                    ),
                ),
                (
                    "money_sources_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FOUTSOURCEOTHER",
                        null=True,
                        verbose_name="If other 'source of payment', please specify ...",
                    ),
                ),
                (
                    "money_source_main",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                            (
                                "family_gift",
                                "Loan from family members that does not need to be repaid",
                            ),
                            ("family_loan", "Loan from family member that needs to be repaid"),
                            (
                                "gift_relative",
                                "Loan from relative/neighbour that does not need to be repaid",
                            ),
                            (
                                "loan_relative",
                                "Loan from relative/neighbour that needs to be repaid",
                            ),
                            ("loan_money_lender", "Loan from money lender"),
                            ("loan_bank", "Loan from another source eg bank"),
                            ("community", "Self-help community group"),
                            ("national_insurance", "National health insurance"),
                            ("private_insurance", "Private health insurance"),
                            ("community_insurance", "Community health insurance"),
                            ("waiver", "Government waiver"),
                            (
                                "asset_sale",
                                "Sale of assets (property, livestock, jewellery, household goods, etc)",
                            ),
                            ("OTHER", "Other (specify)"),
                        ],
                        max_length=25,
                        metadata="FOUTSOURCEMAIN1",
                        verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
                    ),
                ),
                (
                    "seek_inpatient_visits",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        metadata="FINDAYS1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(1),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="How many days in total were you admitted as an INPATIENT?",
                    ),
                ),
                (
                    "inpatient_reasons_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FINDAYSCOND1",
                        null=True,
                        verbose_name="If other 'INPATIENT care' reason, please specify ...",
                    ),
                ),
                (
                    "inpatient_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FINCOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent in total on your hospital stay?",
                    ),
                ),
                (
                    "inpatient_accompany",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        help_text="for example: guesthouse, hotel, friend or relative’s house",
                        max_length=15,
                        metadata="FINACMP1",
                        verbose_name="Did anyone stay with you at the facility or somewhere else at night?",
                    ),
                ),
                (
                    "inpatient_food",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("dont_know", "Don't know"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        metadata="FINFOOD1",
                        verbose_name="When you were first admitted to the facility, was any food and drink bought for people who accompanied you?",
                    ),
                ),
                (
                    "inpatient_food_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FINFOODCOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on this food and drink?",
                    ),
                ),
                (
                    "inpatient_nowork_days",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        metadata="FINWRKMISS1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(90),
                        ],
                        verbose_name="When you were ill, how many days were you not able to go to work?",
                    ),
                ),
                (
                    "inpatient_accompany_nowork",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        metadata="FINOWRKMISS1",
                        verbose_name="Apart from the person that accompanied you, was there anyone else in your household who could not go to work because of your illness?",
                    ),
                ),
                (
                    "inpatient_accompany_nowork_days",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        metadata="FINODAYSMISS1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(90),
                        ],
                        verbose_name="How many days did they not go to work?",
                    ),
                ),
                (
                    "inpatient_money_sources_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FINSOURCEOTHER",
                        null=True,
                        verbose_name="If other 'source of payment', please specify ...",
                    ),
                ),
                (
                    "inpatient_money_sources_main_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FINSOURCEMAIN1OTHER",
                        null=True,
                        verbose_name="If other main 'source of payment', please specify ...",
                    ),
                ),
                (
                    "accompany",
                    edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                        metadata="FOUTACMP1",
                        to="intecomm_lists.accompanied",
                        verbose_name="Who accompanied you to your last/most recent visit?",
                    ),
                ),
                (
                    "inpatient_money_sources",
                    edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                        help_text="Select up to three sources. If ‘other’, please specify.",
                        metadata="FINSOURCE",
                        related_name="%(app_label)s_inpatient_money_sources_related",
                        related_query_name="%(app_label)s_inpatient_money_sources",
                        to="intecomm_lists.moneysources",
                        verbose_name="What were the source(s) of payment for all these expenses for your hospital stay?",
                    ),
                ),
                (
                    "inpatient_money_sources_main",
                    edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                        metadata="FINSOURCEMAIN1",
                        related_name="%(app_label)s_inpatient_money_sources_main_related",
                        related_query_name="%(app_label)s_inpatient_money_main_sources",
                        to="intecomm_lists.moneysources",
                        verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
                    ),
                ),
                (
                    "inpatient_reasons",
                    edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                        metadata="FINDAYSCOND1",
                        related_name="%(app_label)s_inpatient_reasons_related",
                        related_query_name="%(app_label)s_inpatient_reasons_sources",
                        to="intecomm_lists.conditions",
                        verbose_name="What was this INPATIENT care for?",
                    ),
                ),
                (
                    "med_conditions",
                    edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                        metadata="FOUTMEDCOND1",
                        related_name="%(app_label)s_med_conditions_related",
                        related_query_name="%(app_label)s_med_conditions_sources",
                        to="intecomm_lists.conditions",
                        verbose_name="What were the medicines were for?",
                    ),
                ),
                (
                    "money_sources",
                    edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                        help_text="Select up to three sources. If ‘other’, please specify.",
                        metadata="FOUTSOURCE",
                        related_name="%(app_label)s_money_sources_related",
                        related_query_name="%(app_label)s_money_sources",
                        to="intecomm_lists.moneysources",
                        verbose_name="Thinking about the expenses you have reported in the past 3 months, and excluding today’s visit, what were the source(s) of payment for all these expenses?  ",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="intecomm_subject.subjectvisit",
                    ),
                ),
                (
                    "travel_method",
                    edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                        metadata="FOUTTRA1",
                        to="intecomm_lists.travelmethods",
                        verbose_name="Thinking about your last/most recent visit, how did you travel to the visit?",
                    ),
                ),
            ],
            options={
                "verbose_name": "Cost of Careseeking: Part B",
                "verbose_name_plural": "Cost of Careseeking: Part B",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "default_manager_name": "objects",
                "indexes": [
                    models.Index(
                        fields=["subject_visit", "site"], name="intecomm_su_subject_32358d_idx"
                    ),
                    models.Index(
                        fields=["subject_visit", "report_datetime"],
                        name="intecomm_su_subject_e2199b_idx",
                    ),
                    models.Index(
                        fields=["modified", "created"], name="intecomm_su_modifie_aeb7ec_idx"
                    ),
                    models.Index(
                        fields=["user_modified", "user_created"],
                        name="intecomm_su_user_mo_d58010_idx",
                    ),
                ],
            },
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CrfCurrentSiteManager()),
            ],
        ),
        migrations.CreateModel(
            name="CareseekingA",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                        verbose_name="Hostname created",
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                        verbose_name="Hostname modified",
                    ),
                ),
                (
                    "device_created",
                    models.CharField(blank=True, max_length=10, verbose_name="Device created"),
                ),
                (
                    "device_modified",
                    models.CharField(
                        blank=True, max_length=10, verbose_name="Device modified"
                    ),
                ),
                (
                    "locale_created",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale created",
                    ),
                ),
                (
                    "locale_modified",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale modified",
                    ),
                ),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("consent_model", models.CharField(editable=False, max_length=50, null=True)),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "travel_time",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        metadata="FTRATIME1",
                        validators=[
                            django.core.validators.RegexValidator(
                                "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                                message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                            )
                        ],
                        verbose_name="How long did it take you to reach here?",
                    ),
                ),
                (
                    "travel_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="in local currency",
                        metadata="FTRAVCOST1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(1),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="Thinking about yourself and anyone that accompanied you, how much was spent on travel from your home to reach here?",
                    ),
                ),
                (
                    "food_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="in local currency",
                        metadata="FFOODCOST1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="Thinking about yourself and anyone that accompanied you, how much did you have to pay for food, drink or other refreshments during your travel or during your visit? (e.g. food, drink, etc.)",
                    ),
                ),
                (
                    "visit_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FFEECOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much money did you spend on healthworker and consultation fees during this visit?",
                    ),
                ),
                (
                    "med_prescribed",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        metadata="FMED1",
                        verbose_name="Were you prescribed any medicines during this visit?",
                    ),
                ),
                (
                    "med_conditions_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FMEDCONDOTHER1",
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "med_collected",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        metadata="FMEDCOLL1",
                        verbose_name="Did you receive/collect these medicines (whether paid or received for free)?",
                    ),
                ),
                (
                    "med_not_collected_reason",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("meds_at_home", "Already had the medicines at home"),
                            ("unavailable", "Medicines were not available"),
                            ("expensive", "Medicines were too expensive"),
                            ("home_remedies", "Home remedies are better"),
                            (
                                "unimportant",
                                "Did not think it was important to get these medicines",
                            ),
                            ("too_busy", "Did not have the time to collect or buy medicines"),
                            ("problematic", "Taking medicines caused problems"),
                            ("OTHER", "Other, please specify ..."),
                        ],
                        max_length=25,
                        metadata="FMED1",
                        verbose_name="Why were these medicines not received/collected?",
                    ),
                ),
                (
                    "med_not_collected_reason_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FMEDOTHER1",
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "med_cost_tot",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FMEDCOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on these medicines? ",
                    ),
                ),
                (
                    "med_cost_hiv",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="Leave blank if not applicable. In local currency",
                        metadata="FMEDCOSTHIV1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on HIV medicines? ",
                    ),
                ),
                (
                    "med_cost_htn",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="Leave blank if not applicable. In local currency",
                        metadata="FMEDCOSTHTN1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on Hypertension medicines? ",
                    ),
                ),
                (
                    "med_cost_dm",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="Leave blank if not applicable. In local currency",
                        metadata="FMEDCOSTDM1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on Diabetes medicines? ",
                    ),
                ),
                (
                    "med_cost_other",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="Leave blank if not applicable. In local currency",
                        metadata="FMEDCOSTOTHER1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much was spent on OTHER medicines? ",
                    ),
                ),
                (
                    "tests_requested",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        metadata="FTEST1",
                        verbose_name="Did the healthcare worker request for any tests to be done during this visit?",
                    ),
                ),
                (
                    "tests_done",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=25,
                        metadata="FTESTDONE1",
                        verbose_name="Were the tests performed?",
                    ),
                ),
                (
                    "tests_not_done_reason",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("unavailable", "Tests were not available"),
                            ("expensive", "Tests were too expensive"),
                            (
                                "unimportant",
                                "Did not think it was important to do these tests ",
                            ),
                            ("too_busy", "Did not have the time to do these tests"),
                            ("OTHER", "Other, please specify ..."),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        metadata="FTESTNO1",
                        verbose_name="Why were the tests not performed?",
                    ),
                ),
                (
                    "tests_not_done_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FTESTNOOTHER1",
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "tests_cost",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        help_text="in local currency",
                        metadata="FTESTCOST1",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999),
                        ],
                        verbose_name="How much did you spend on these tests?",
                    ),
                ),
                (
                    "facility_duration",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        metadata="FFACTIME1",
                        validators=[
                            django.core.validators.RegexValidator(
                                "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                                message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                            )
                        ],
                        verbose_name="How much time did you spend during your visit today -- from arrival to this place until the end of your visit?",
                    ),
                ),
                (
                    "wait_duration",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        metadata="FWAITIME1",
                        validators=[
                            django.core.validators.RegexValidator(
                                "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                                message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                            )
                        ],
                        verbose_name="How much time did you spend waiting?",
                    ),
                ),
                (
                    "hworker_duration",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        metadata="FWORKTIME1",
                        validators=[
                            django.core.validators.RegexValidator(
                                "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                                message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                            )
                        ],
                        verbose_name="How much time did you spend with the healthcare worker?",
                    ),
                ),
                (
                    "facility_visit_alt",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            (
                                "paid_work",
                                "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                            ),
                            (
                                "unpaid_work",
                                "Unpaid work (e.g. subsistence farming, housework etc.)",
                            ),
                            ("OTHER", "Other (specify)"),
                        ],
                        max_length=25,
                        metadata="FACTIVITY1",
                        verbose_name="If you were not attending the visit today, what would you have been doing?",
                    ),
                ),
                (
                    "alt_lost_income",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency. Ask for cash value or equivalent cash value for in-kind",
                        metadata="FPAID1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="How much would you have made in cash or in-kind for a day’s work?",
                    ),
                ),
                (
                    "referral",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        metadata="FREFER1",
                        verbose_name="As a result of your visit today, have you been referred for further care?",
                    ),
                ),
                (
                    "referral_type",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("inpatient", "Inpatient"),
                            ("outpatient", "Outpatient (includes laboratory testing)"),
                        ],
                        max_length=25,
                        metadata="FREFTYPE1",
                        verbose_name="Is this for inpatient or outpatient care?",
                    ),
                ),
                (
                    "referral_facility",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("public_clinic", "Public facility below tertiary level"),
                            ("private_clinic", "Private clinic"),
                            ("private_dx_facility", "Private diagnostic facility"),
                            ("ngo_clinic", "NGO clinic"),
                            ("public_hospital", "Public Hospital/tertiary facility"),
                            ("private_hospital", "Private hospital"),
                            ("pharmacy", "Pharmacy"),
                        ],
                        max_length=25,
                        metadata="FREFAC1",
                        verbose_name="What type of facility have you been referred to?",
                    ),
                ),
                (
                    "accompany_num",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        metadata="FACMP1"
                    ),
                ),
                (
                    "accompany_wait",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        metadata="FACMPWAIT1",
                        verbose_name="Did the people accompanying you wait for you during the visit?",
                    ),
                ),
                (
                    "accompany_alt",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        blank=True,
                        choices=[
                            (
                                "paid_work",
                                "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                            ),
                            (
                                "unpaid_work",
                                "Unpaid work (e.g. subsistence farming, housework etc.)",
                            ),
                            ("OTHER", "Other (specify)"),
                        ],
                        max_length=25,
                        metadata="FACMPACT1",
                        null=True,
                        verbose_name="If those accompanying you were not attending the visit with you today, what would they have been doing?",
                    ),
                ),
                (
                    "accompany_lost_income",
                    edc_model_fields.fields.custom_django_fields.IntegerField2(
                        blank=True,
                        help_text="In local currency. Ask for cash value or equivalent cash value for in-kind",
                        metadata="FACMP1",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(9999999999),
                        ],
                        verbose_name="How much would they have made in cash or in-kind for a day’s work?",
                    ),
                ),
                (
                    "money_sources_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        metadata="FTODSOURCEOTHER",
                        null=True,
                        verbose_name="If other 'source of payment', please specify ...",
                    ),
                ),
                (
                    "money_source_main",
                    edc_model_fields.fields.custom_django_fields.CharField2(
                        choices=[
                            ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                            (
                                "family_gift",
                                "Loan from family members that does not need to be repaid",
                            ),
                            ("family_loan", "Loan from family member that needs to be repaid"),
                            (
                                "gift_relative",
                                "Loan from relative/neighbour that does not need to be repaid",
                            ),
                            (
                                "loan_relative",
                                "Loan from relative/neighbour that needs to be repaid",
                            ),
                            ("loan_money_lender", "Loan from money lender"),
                            ("loan_bank", "Loan from another source eg bank"),
                            ("community", "Self-help community group"),
                            ("national_insurance", "National health insurance"),
                            ("private_insurance", "Private health insurance"),
                            ("community_insurance", "Community health insurance"),
                            ("waiver", "Government waiver"),
                            (
                                "asset_sale",
                                "Sale of assets (property, livestock, jewellery, household goods, etc)",
                            ),
                            ("OTHER", "Other (specify)"),
                        ],
                        max_length=25,
                        metadata="FTODSOURCEMAIN1",
                        verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
                    ),
                ),
                (
                    "money_source_main_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other main 'source of payment', please specify ...",
                    ),
                ),
                (
                    "accompany",
                    edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                        metadata="FACMP1",
                        to="intecomm_lists.accompanied",
                        verbose_name="Who accompanied you here today?",
                    ),
                ),
                (
                    "med_conditions",
                    edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                        metadata="FMEDCOND1",
                        to="intecomm_lists.conditions",
                        verbose_name="What were the medicines were for?",
                    ),
                ),
                (
                    "money_sources",
                    edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                        help_text="Select up to three sources. If ‘other’, please specify.",
                        metadata="FTODSOURCE",
                        to="intecomm_lists.moneysources",
                        verbose_name="Thinking about the expenses you have reported for today’s visit, what were the source(s) of payment for all these expenses?",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="intecomm_subject.subjectvisit",
                    ),
                ),
                (
                    "travel_method",
                    edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                        metadata="FTRA1",
                        to="intecomm_lists.travelmethods",
                        verbose_name="How did you travel here?",
                    ),
                ),
                (
                    "visit_reason",
                    edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                        metadata="FMEDCOND1",
                        to="intecomm_lists.visitreasons",
                        verbose_name="What was the reason for today’s visit?",
                    ),
                ),
            ],
            options={
                "verbose_name": "Cost of Careseeking: Part A",
                "verbose_name_plural": "Cost of Careseeking: Part A",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "default_manager_name": "objects",
                "indexes": [
                    models.Index(
                        fields=["subject_visit", "site"], name="intecomm_su_subject_8c3529_idx"
                    ),
                    models.Index(
                        fields=["subject_visit", "report_datetime"],
                        name="intecomm_su_subject_1366c1_idx",
                    ),
                    models.Index(
                        fields=["modified", "created"], name="intecomm_su_modifie_7eb7c4_idx"
                    ),
                    models.Index(
                        fields=["user_modified", "user_created"],
                        name="intecomm_su_user_mo_f49209_idx",
                    ),
                ],
            },
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CrfCurrentSiteManager()),
            ],
        ),
    ]



from django.db import models
from edc_action_item.models import ActionModelMixin
from edc_adverse_event.constants import AE_INITIAL_ACTION
from edc_adverse_event.model_mixins.ae_initial import (
    AeInitialFieldsModelMixin,
    AeInitialMethodsModelMixin,
)
from edc_adverse_event.models import AeClassification
from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
from edc_model.models import BaseUuidModel
from edc_model_fields.fields import OtherCharField
from edc_sites.model_mixins import SiteModelMixin

from ..pdf_reports import AePdfReport


class AeInitial(
    SiteModelMixin,
    ActionModelMixin,
    NonUniqueSubjectIdentifierFieldMixin,
    AeInitialFieldsModelMixin,
    AeInitialMethodsModelMixin,
    BaseUuidModel,
):
    action_name = AE_INITIAL_ACTION
    pdf_report_cls = AePdfReport

    ae_classification_as_text = models.CharField(
        verbose_name="Adverse Event (AE) Classification",
        max_length=150,
        null=True,
        blank=False,
        help_text="Keep this simple. Provide details below",
    )

    ae_classification = models.ForeignKey(
        AeClassification,
        on_delete=models.PROTECT,
        verbose_name="Adverse Event (AE) Classification",
        null=True,
        editable=False,
    )

    study_drug_relation = models.CharField(
        verbose_name="Relation to study drug:", max_length=25, null=True, editable=False
    )

    ae_classification_other = OtherCharField(max_length=250, null=True, editable=False)

    ae_treatment = models.TextField(verbose_name="Specify action taken for treatment of AE:")

    class Meta(
        NonUniqueSubjectIdentifierFieldMixin.Meta, ActionModelMixin.Meta, BaseUuidModel.Meta
    ):
        indexes = (
            NonUniqueSubjectIdentifierFieldMixin.Meta.indexes
            + ActionModelMixin.Meta.indexes
            + BaseUuidModel.Meta.indexes
        )



# Generated by Django 4.2.11 on 2024-06-21 13:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_reports", "0002_diagnoses"),
    ]

    operations = [
        migrations.AddField(
            model_name="diagnoses",
            name="baseline",
            field=models.IntegerField(
                default=0,
                help_text="Number of diagnoses that qualify as baseline (182 days before baseline)",
            ),
        ),
    ]



from textwrap import fill

from edc_adverse_event.pdf_reports import DeathPdfReport as BaseDeathReport
from reportlab.lib.units import cm
from reportlab.platypus import Table


class DeathPdfReport(BaseDeathReport):
    weight_model = "intecomm_subject.followup"
    logo_data = {
        "app_label": "intecomm_edc",
        "filename": "meta_logo.png",
        "first_page": (4.0 * cm, 0.83 * cm),
        "later_pages": (3.0 * cm, 0.625 * cm),
    }

    def _draw_opinion(self, story):
        t = Table([["Section 2: Opinion of Local Study Doctor"]], (18 * cm))
        self.set_table_style(t, bg_cmd=self.bg_cmd)
        story.append(t)
        rows = []

        row = ["Main cause of death:"]
        if not self.death_report.cause_of_death:
            row.append(self.not_reported_text)
        else:
            row.append(fill(self.death_report.cause_of_death))
        rows.append(row)

        t = Table(rows, (4 * cm, 14 * cm))
        self.set_table_style(t, bg_cmd=self.bg_cmd)
        t.hAlign = "LEFT"
        story.append(t)

        self.draw_narrative(story, title="Narrative:", text=self.death_report.narrative)



from django.contrib import admin
from django.template.loader import render_to_string
from django.urls import reverse
from edc_model_admin.dashboard import ModelAdminDashboardMixin
from edc_model_admin.mixins import TemplatesModelAdminMixin
from edc_qareports.modeladmin_mixins import QaReportModelAdminMixin
from edc_sites.admin import SiteModelAdminMixin

from ...admin_site import intecomm_reports_admin
from ...models import Vl
from ..list_filters import ScheduleStatusListFilter, VlDateListFilter, VlListFilter


@admin.register(Vl, site=intecomm_reports_admin)
class VlAdmin(
    QaReportModelAdminMixin,
    SiteModelAdminMixin,
    ModelAdminDashboardMixin,
    TemplatesModelAdminMixin,
    admin.ModelAdmin,
):
    include_note_column = False
    ordering = ["site", "subject_identifier"]

    list_display = [
        "dashboard",
        "subject",
        "vl_value",
        "baseline_date",
        "vl_date",
        "m",
        "site",
        "created",
    ]

    list_filter = [VlListFilter, VlDateListFilter, ScheduleStatusListFilter]

    search_fields = ["id", "subject_identifier", "vl_value"]

    @admin.display(description="Subject", ordering="subject_identifier")
    def subject(self, obj):
        url = reverse("intecomm_reports_admin:intecomm_reports_vl_changelist")
        context = dict(url=url, subject_identifier=obj.subject_identifier)
        return render_to_string(
            "intecomm_reports/columns/vl_subject_identifier.html", context=context
        )



from multisite import SiteID

from .defaults import *  # noqa

print(f"Settings file {__file__}")


DJANGO_DEBUG_TOOLBAR_ENABLED = False
SITE_ID = SiteID(default=1)
EDC_SITES_UAT_DOMAIN = False
ALLOWED_HOSTS = [
    "kasangati.ug.intecomm.clinicedc.org",
    "kisugu.ug.intecomm.clinicedc.org",
    "kiswa.ug.intecomm.clinicedc.org",
    "kyazanga.ug.intecomm.clinicedc.org",
    "mpigi.ug.intecomm.clinicedc.org",
    "namayumba.ug.intecomm.clinicedc.org",
    "namulonge.ug.intecomm.clinicedc.org",
    "ndejje.ug.intecomm.clinicedc.org",
    "sekiwunga.ug.intecomm.clinicedc.org",
    "wakiso.ug.intecomm.clinicedc.org",
    "amana.tz.intecomm.clinicedc.org",
    "bagamoyo.tz.intecomm.clinicedc.org",
    "rugambwa.tz.intecomm.clinicedc.org",
    "hindu-mandal.tz.intecomm.clinicedc.org",
    "kisarawe.tz.intecomm.clinicedc.org",
    "mbagala.tz.intecomm.clinicedc.org",
    "mnazi.tz.intecomm.clinicedc.org",
    "mwananyamala.tz.intecomm.clinicedc.org",
    "sinza.tz.intecomm.clinicedc.org",
    "temeke.tz.intecomm.clinicedc.org",
]
EDC_MODEL_ADMIN_CSS_THEME = "edc_indigo"
LIVE_SYSTEM = True



# Generated by Django 4.1.2 on 2022-11-20 21:41

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_group", "0002_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalpatientgroup",
            name="group_identifier",
            field=models.CharField(max_length=36, null=True),
        ),
        migrations.AlterField(
            model_name="patientgroup",
            name="group_identifier",
            field=models.CharField(max_length=36, null=True),
        ),
    ]



from django.core.validators import MaxValueValidator, MinValueValidator
from django.db.models import DurationField as DjangoDurationField
from django.utils.translation import gettext as _
from edc_constants.choices import YES_NO, YES_NO_DONT_KNOW_NA, YES_NO_NA
from edc_constants.constants import DM, HIV, HTN, NOT_APPLICABLE, OTHER
from edc_model.models import BaseUuidModel
from edc_model.utils import duration_hm_to_timedelta
from edc_model_fields.fields import (
    CharField2,
    IntegerField2,
    ManyToManyField2,
    OtherCharField,
)

from intecomm_lists.models import Conditions, MoneySources, TravelMethods

from ...choices import (
    ACCOMPANIED_BY_NA,
    FACILITY_VISIT_ALTERNATIVES_NA,
    MONEY_SOURCES_NA,
    NO_SEEK_REASONS,
    NOT_COLLECTED_REASONS,
    SEEK_FACILITIES,
    SEEKK_CARE_TYPES,
    TESTS_NOT_DONE_REASONS,
)
from ...model_mixins import CrfModelMixin
from ..fields import DurationAsStringField, ExpenseField


class CareseekingB(CrfModelMixin, BaseUuidModel):

    needed_care = CharField2(
        verbose_name=_(
            "Other than today’s visit, and thinking about the past 3 months, "
            "did you need to make any routine visits or were you ill or in need of "
            "healthcare at any point for HIV, Hypertension, Diabetes or anything "
            "related to you having these conditions?"
        ),
        max_length=15,
        choices=YES_NO,
        metadata="FILLMONTH1",
    )

    accessed_care = CharField2(
        verbose_name=_(
            "Did you make the visit, seek advice or treatment "
            "(public facility, local pharmacy, traditional doctor etc)?"
        ),
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        metadata="FSEEK1",
    )

    no_accessed_care = CharField2(
        verbose_name=_("If no, why did you not make the visit, seek advice or treatment?"),
        max_length=25,
        choices=NO_SEEK_REASONS(),
        default=NOT_APPLICABLE,
        help_text="If NO, STOP and SAVE form",
        metadata="FNOSEEK1",
    )

    no_accessed_care_other = OtherCharField(verbose_name="If OTHER reason, please explain ...")

    care_facility = CharField2(
        verbose_name=_("If yes, where did you make the visit, seek advice or treatment?"),
        max_length=25,
        choices=SEEK_FACILITIES(),
        default=NOT_APPLICABLE,
        metadata="FSEEKFAC1",
    )

    care_facility_other = OtherCharField(verbose_name="If OTHER place, please explain ...")

    care_type = CharField2(
        verbose_name=_("If yes, what type of care was this?"),
        max_length=25,
        choices=SEEKK_CARE_TYPES(),
        default=NOT_APPLICABLE,
        metadata="FSEEKTYPE1",
    )

    outpatient_visits = IntegerField2(
        verbose_name=_("If yes and OUTPATIENT or BOTH, how many outpatient visits in total?"),
        validators=[MinValueValidator(1), MaxValueValidator(10)],
        null=True,
        blank=True,
        metadata="FOUT1",
    )

    travel_method = ManyToManyField2(
        TravelMethods,
        verbose_name=_(
            "Thinking about your last/most recent visit, how did you travel to the visit?"
        ),
        blank=True,
        metadata="FOUTTRA1",
    )

    travel_duration = DurationAsStringField(
        verbose_name=_("How long did it take you to get there?"),
        metadata="FOUTTRATIME1",
    )

    travel_tdelta = DjangoDurationField(
        null=True,
        blank=True,
        editable=False,
    )

    travel_costs = ExpenseField(
        verbose_name=_(
            "Thinking about yourself and anyone that accompanied you, how much was spent "
            "on travel from your home to your last/most recent visit?"
        ),
        metadata="FOUTTRACOST1",
    )

    food_costs = ExpenseField(
        verbose_name=_(
            "Thinking about yourself and anyone that accompanied you, did you have to pay "
            "for food, drink or other refreshments during your travel or during your "
            "last/most recent visit? (e.g. food, drink, etc.)"
        ),
        metadata="FOUTFOODCOST1",
    )

    care_costs = ExpenseField(
        verbose_name=_(
            "How much money did you spend on healthworker and consultation fees "
            "during your last/most recent visit?"
        ),
        metadata="FOUTFEECOST1",
    )

    med_prescribed = CharField2(
        verbose_name=_(
            "Were you prescribed any medicines during your last/most recent visit?"
        ),
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        metadata="FOUTMED1",
    )

    med_conditions = ManyToManyField2(
        Conditions,
        limit_choices_to={"name__in": [HIV, DM, HTN, OTHER]},
        related_name="%(app_label)s_med_conditions_related",
        related_query_name="%(app_label)s_med_conditions_sources",
        verbose_name=_("What were the medicines were for?"),
        blank=True,
        metadata="FOUTMEDCOND1",
    )

    med_conditions_other = OtherCharField(metadata="FOUTMEDCONDOTHER1")

    med_collected = CharField2(
        verbose_name=_(
            "Did you receive/collect these medicines (whether paid or received for free)?"
        ),
        max_length=25,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        metadata="FOUTMEDCOLL1",
    )

    med_not_collected_reason = CharField2(
        verbose_name=_("Why were these medicines not received/collected?"),
        max_length=25,
        choices=NOT_COLLECTED_REASONS(),
        default=NOT_APPLICABLE,
        metadata="FOUTMEDNO1",
    )

    med_not_collected_reason_other = OtherCharField(metadata="FOUTMEDNOOTHER1")

    med_cost_tot = ExpenseField(
        verbose_name=_("How much was spent on these medicines? "),
        metadata="FOUTMEDCOST1",
    )

    tests_requested = CharField2(
        verbose_name=_(
            "Did the healthcare worker request for any tests to be done during "
            "your last/most recent visit?"
        ),
        max_length=25,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        help_text=_("for example, blood pressure, viral load, glucose etc."),
        metadata="FOUTTEST1",
    )

    tests_done = CharField2(
        verbose_name=_("Were the tests performed?"),
        max_length=25,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        help_text=_("select YES even if done elsewhere / another facility"),
        metadata="FOUTTESTDONE1",
    )

    tests_not_done_reason = CharField2(
        verbose_name=_("Why were the tests not performed?"),
        max_length=25,
        choices=TESTS_NOT_DONE_REASONS(),
        default=NOT_APPLICABLE,
        metadata="FOUTTESTNO1",
    )

    tests_not_done_other = OtherCharField(metadata="FOUTTESTNOOTHER1")

    tests_cost = ExpenseField(
        verbose_name=_("How much did you spend on these tests?"),
        metadata="FOUTTESTCOST1",
    )

    care_visit_duration = DurationAsStringField(
        verbose_name=_(
            "Roughly how much time did you spend during your last/most recent visit?"
        ),
        metadata="FOUTTIME1",
    )

    care_visit_tdelta = DjangoDurationField(
        null=True,
        blank=True,
        editable=False,
    )

    missed_activities = CharField2(
        verbose_name=_("If you were not attending the visit, what would you have been doing?"),
        max_length=25,
        null=True,
        blank=False,
        default=NOT_APPLICABLE,
        choices=FACILITY_VISIT_ALTERNATIVES_NA(),
        metadata="FOUTACTIVITY1",
    )

    missed_activities_other = OtherCharField(metadata="FMEDOTHER1")

    accompany = CharField2(
        verbose_name="Who accompanied you to your last/most recent visit?",
        max_length=25,
        choices=ACCOMPANIED_BY_NA(),
        default=NOT_APPLICABLE,
        null=True,
        blank=False,
        metadata="FOUTACMP1",
    )

    accompany_num = IntegerField2(
        verbose_name=_("Number of people who accompanied you to your last/most recent visit"),
        null=True,
        blank=True,
        metadata="FOUTACMPNUM1",
    )

    accompany_wait = CharField2(
        verbose_name=_(
            "Did the people accompanying you wait for you during your last/most recent visit?"
        ),
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        metadata="FOUTACMPWAIT1",
    )

    accompany_alt = CharField2(
        verbose_name=_(
            "If those accompanying you were not attending your last/most recent visit "
            "with you, what would they have been doing?"
        ),
        max_length=25,
        choices=FACILITY_VISIT_ALTERNATIVES_NA(),
        default=NOT_APPLICABLE,
        metadata="FOUTACMPACT1",
    )

    accompany_alt_other = OtherCharField(metadata="FOUTACMPACTOTHER1")

    money_sources = ManyToManyField2(
        MoneySources,
        related_name="%(app_label)s_money_sources_related",
        related_query_name="%(app_label)s_money_sources",
        verbose_name=_(
            "Thinking about the expenses you have reported in the past 3 months, and "
            "excluding today’s visit, what were the source(s) of payment for all "
            "these expenses?  "
        ),
        blank=True,
        help_text="Select up to three sources. If 'other', please specify.",
        metadata="FOUTSOURCE",
    )

    money_sources_other = OtherCharField(
        verbose_name=_("If other 'source of payment', please specify ..."),
        metadata="FOUTSOURCEOTHER",
    )

    money_source_main = CharField2(
        verbose_name=_(
            "Of the various sources that you have just mentioned, "
            "what was the main source of payment?"
        ),
        max_length=25,
        choices=MONEY_SOURCES_NA(),
        default=NOT_APPLICABLE,
        metadata="FOUTSOURCEMAIN1",
    )

    inpatient = CharField2(
        verbose_name="Were you admitted as a INPATIENT?",
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        help_text="If NO, STOP and SAVE.",
    )

    inpatient_days = IntegerField2(
        verbose_name=_("How many days in total were you admitted as an INPATIENT?"),
        validators=[MinValueValidator(1), MaxValueValidator(10)],
        null=True,
        blank=True,
        metadata="FINDAYS1",
    )

    inpatient_reasons = ManyToManyField2(
        Conditions,
        related_name="%(app_label)s_inpatient_reasons_related",
        related_query_name="%(app_label)s_inpatient_reasons_sources",
        verbose_name=_("What was this INPATIENT care for?"),
        blank=True,
        metadata="FINDAYSCOND1",
    )

    inpatient_reasons_other = OtherCharField(
        verbose_name=_("If other 'INPATIENT care' reason, please specify ..."),
        metadata="FINDAYSCOND1",
    )

    inpatient_cost = ExpenseField(
        verbose_name=_("How much was spent in total on your hospital stay?"),
        metadata="FINCOST1",
    )

    inpatient_accompany = CharField2(
        verbose_name=_("Did anyone stay with you at the facility or somewhere else at night?"),
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        help_text=_("for example: guesthouse, hotel, friend or relative’s house"),
        metadata="FINACMP1",
    )

    inpatient_food = CharField2(
        verbose_name=_(
            "When you were first admitted to the facility, was any food and drink bought "
            "for people who accompanied you?"
        ),
        max_length=15,
        choices=YES_NO_DONT_KNOW_NA,
        default=NOT_APPLICABLE,
        metadata="FINFOOD1",
    )

    inpatient_food_cost = ExpenseField(
        verbose_name=_("How much was spent on this food and drink?"),
        metadata="FINFOODCOST1",
    )

    inpatient_nowork_days = IntegerField2(
        verbose_name="When you were ill, how many days were you not able to go to work?",
        validators=[MinValueValidator(0), MaxValueValidator(90)],
        null=True,
        blank=True,
        metadata="FINWRKMISS1",
    )

    inpatient_household_nowork = CharField2(
        verbose_name=_(
            "Apart from the person that accompanied you, was there anyone "
            "else in your household who could not go to work because of your illness?"
        ),
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
        metadata="FINOWRKMISS1",
    )

    inpatient_household_nowork_days = IntegerField2(
        verbose_name="How many days did they not go to work?",
        validators=[MinValueValidator(0), MaxValueValidator(90)],
        null=True,
        blank=True,
        metadata="FINODAYSMISS1",
    )

    inpatient_money_sources = ManyToManyField2(
        MoneySources,
        related_name="%(app_label)s_inpatient_money_sources_related",
        related_query_name="%(app_label)s_inpatient_money_sources",
        verbose_name=_(
            "What were the source(s) of payment for all these expenses for your hospital stay?"
        ),
        blank=True,
        help_text="Select up to three sources. If 'other', please specify.",
        metadata="FINSOURCE",
    )

    inpatient_money_sources_other = OtherCharField(
        verbose_name=_("If other 'source of payment', please specify ..."),
        metadata="FINSOURCEOTHER",
    )

    inpatient_money_sources_main = CharField2(
        verbose_name=_(
            "Of the various sources that you have just mentioned, "
            "what was the main source of payment?"
        ),
        max_length=25,
        choices=MONEY_SOURCES_NA(),
        default=NOT_APPLICABLE,
        metadata="FINSOURCEMAIN1",
    )

    inpatient_money_sources_main_other = OtherCharField(
        verbose_name=_("If other main 'source of payment', please specify ..."),
        metadata="FINSOURCEMAIN1OTHER",
    )

    def save(self, *args, **kwargs):
        if self.travel_duration:
            self.travel_tdelta = duration_hm_to_timedelta(self.travel_duration)
        if self.care_visit_duration:
            self.care_visit_tdelta = duration_hm_to_timedelta(self.care_visit_duration)
        super().save(*args, **kwargs)

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Cost of Careseeking: Part B"
        verbose_name_plural = "Cost of Careseeking: Part B"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



# Generated by Django 4.2.11 on 2024-04-22 16:45

from django.db import migrations, models
import edc_model.models.fields.other_charfield


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        (
            "intecomm_subject",
            "0179_rename_managed_by_historicalhtnreview_managed_by_old_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalhtnreview",
            name="managed_by_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="htnreview",
            name="managed_by",
            field=models.ManyToManyField(
                to="intecomm_lists.htnmanagement",
                verbose_name="How will the patient's hypertension be managed going forward?",
            ),
        ),
        migrations.AddField(
            model_name="htnreview",
            name="managed_by_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
    ]



# Generated by Django 4.1.7 on 2023-04-17 18:58

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0027_dminitialreview_rx_init_dminitialreview_rx_init_date_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="dm_test",
        ),
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="dm_test_ago",
        ),
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="dm_test_date",
        ),
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="dm_test_estimated_date",
        ),
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="hiv_test",
        ),
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="hiv_test_ago",
        ),
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="hiv_test_date",
        ),
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="hiv_test_estimated_date",
        ),
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="htn_test",
        ),
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="htn_test_ago",
        ),
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="htn_test_date",
        ),
        migrations.RemoveField(
            model_name="clinicalreviewbaseline",
            name="htn_test_estimated_date",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="dm_test",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="dm_test_ago",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="dm_test_date",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="dm_test_estimated_date",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="hiv_test",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="hiv_test_ago",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="hiv_test_date",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="hiv_test_estimated_date",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="htn_test",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="htn_test_ago",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="htn_test_date",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreviewbaseline",
            name="htn_test_estimated_date",
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="dm_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Has the patient ever been diagnosed with Diabetes",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="hiv_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="htn_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Has the patient ever been diagnosed with Hypertension",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="dm_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Has the patient ever been diagnosed with Diabetes",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="hiv_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="htn_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Has the patient ever been diagnosed with Hypertension",
            ),
        ),
    ]



from django import forms
from edc_form_validators import INVALID_ERROR, FormValidator, FormValidatorMixin

from ..models import PatientGroup


class PatientGroupFormValidator(FormValidator):
    def clean(self):
        self.raise_validation_error({"__all__": "This form may not be changed"}, INVALID_ERROR)


class PatientGroupForm(FormValidatorMixin, forms.ModelForm):
    form_validator_cls = PatientGroupFormValidator

    class Meta:
        model = PatientGroup
        fields = "__all__"



# Generated by Django 4.1.7 on 2023-04-20 01:29

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0033_clinicalreviewbaseline_dm_dx_at_screening_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="clinicalreviewbaseline",
            name="protocol_incident",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Do any of the above diagnosis differ from those reported at screening?",
            ),
        ),
        migrations.AddField(
            model_name="historicalclinicalreviewbaseline",
            name="protocol_incident",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Do any of the above diagnosis differ from those reported at screening?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="dm_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Has the patient ever been diagnosed with DIABETES?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="dm_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was a diagnosis of DIABETES reported at screening?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="hiv_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was a diagnosis of HIV reported at screening?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="htn_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Has the patient ever been diagnosed with HYPERTENSION?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="htn_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was a diagnosis of HYPERTENSION reported at screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="dm_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Has the patient ever been diagnosed with DIABETES?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="dm_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was a diagnosis of DIABETES reported at screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="hiv_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was a diagnosis of HIV reported at screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="htn_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Has the patient ever been diagnosed with HYPERTENSION?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="htn_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was a diagnosis of HYPERTENSION reported at screening?",
            ),
        ),
    ]



# Generated by Django 5.0.4 on 2024-04-10 21:30

import django.core.validators
import edc_model_fields.fields.custom_django_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0157_alter_careseekingb_med_conditions_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="careseekingb",
            name="med_collected",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                metadata="FOUTMEDCOLL1",
                verbose_name="Did you receive/collect these medicines (whether paid or received for free)?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="med_cost_tot",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FOUTMEDCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much was spent on these medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="tests_cost",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FOUTTESTCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much did you spend on these tests?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="med_collected",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                metadata="FOUTMEDCOLL1",
                verbose_name="Did you receive/collect these medicines (whether paid or received for free)?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="med_cost_tot",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FOUTMEDCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much was spent on these medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="tests_cost",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FOUTTESTCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much did you spend on these tests?",
            ),
        ),
    ]



# Generated by Django 4.2.11 on 2024-07-02 01:06

from django.db import migrations, models
import django.db.models.deletion
import edc_sites.managers
import edc_utils.date


class Migration(migrations.Migration):

    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        (
            "intecomm_reports",
            "0004_remove_diagnoses_baseline_diagnoses_baseline_182d_and_more",
        ),
    ]

    operations = [
        migrations.CreateModel(
            name="Vl",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=25)),
                (
                    "report_model",
                    models.CharField(default="intecomm_reports.vl", max_length=50),
                ),
                ("created", models.DateTimeField(default=edc_utils.date.get_utcnow)),
                ("baseline_date", models.DateField(null=True)),
                ("baseline_vl_date", models.DateField(null=True)),
                ("endline_vl_date", models.DateField(null=True)),
                ("baseline_vl", models.IntegerField(null=True)),
                ("endline_vl", models.IntegerField(null=True)),
            ],
            options={
                "verbose_name": "Viral load summary",
                "verbose_name_plural": "Viral load summary",
                "db_table": "intecomm_reports_vl_view",
                "managed": False,
            },
            managers=[
                ("on_site", edc_sites.managers.CurrentSiteManager()),
            ],
        ),
        migrations.CreateModel(
            name="VlSummary",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50, unique=True)),
                (
                    "report_model",
                    models.CharField(default="intecomm_reports.vlsummary", max_length=50),
                ),
                ("created", models.DateTimeField(default=edc_utils.date.get_utcnow)),
                ("baseline_date", models.DateField(null=True)),
                ("baseline_vl_date", models.DateField(null=True)),
                ("endline_vl_date", models.DateField(null=True)),
                ("baseline_vl", models.IntegerField(null=True)),
                ("endline_vl", models.IntegerField(null=True)),
                (
                    "site",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT, to="sites.site"
                    ),
                ),
            ],
            options={
                "verbose_name": "Viral load summary",
                "verbose_name_plural": "Viral load summary",
            },
            managers=[
                ("on_site", edc_sites.managers.CurrentSiteManager()),
            ],
        ),
    ]



from edc_dx.diagnoses import DiagnosesError
from edc_dx_review.model_mixins.factory.calculate_date import update_calculated_date
from edc_model.utils import get_report_datetime_field_name
from edc_utils import get_utcnow
from tqdm import tqdm

from .models import DmInitialReview, HivInitialReview, HtnInitialReview


def recalculate_dx_calculated_date(
    models: dict | None = None, subject_identifier: str | None = None
):
    errors = []
    models = models or {
        "hiv": HivInitialReview,
        "htn": HtnInitialReview,
        "dm": DmInitialReview,
    }
    for fld_prefix, model_cls in models.items():
        opts = {}
        disable_tqdm = False
        if subject_identifier:
            opts = dict(subject_visit__subject_identifier=subject_identifier)
            disable_tqdm = True
        qs = model_cls.objects.filter(**opts)
        total = qs.count()
        for obj in tqdm(qs, total=total, disable=disable_tqdm):
            subject_identifier = obj.subject_visit.subject_identifier
            update_calculated_date(
                obj,
                fld_prefix="dx",
                reference_field=get_report_datetime_field_name(),
            )
            obj.modified = get_utcnow()
            obj.user_modified = "erikvw"
            try:
                obj.save_base(
                    update_fields=[
                        "dx_calculated_date",
                        "dx_date_is_estimated",
                        "modified",
                        "user_modified",
                    ]
                )
            except DiagnosesError as e:
                errors.append(f"{subject_identifier}. {e}")
    for err in errors:
        print(err)
